﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections.ObjectModel;
using System.Threading;
using System.Windows;
using System.Xml.Serialization;
using System.Globalization;
using System.Data;

namespace WpfMultiCombo
{
    public class PlantArticles : ObservableCollection<PlantArticle>
    {
        public PlantArticles()
            : base()
        {
        }

        public PlantArticles(IEnumerable<PlantArticle> articles, Plant plant)
            : base(articles)
        {
            this.Plant = plant;
        }

        public PlantArticles(List<PlantArticle> articles, Plant plant)
            : base(articles)
        {
            this.Plant = plant;
        }

        public PlantArticles(DataTable table, Plant plant, bool allloaded = false)
            : base(table.AsEnumerable().Select(row => new PlantArticle
            {
                ArticleNo = row.Field<int>("ArticleNo"),
                CompanyArticleOrgNo = row.Field<Int16>("CompanyArticleOrgNo"),
                SourceNo = row.Field<int>("SourceNo"),
                SourceArticleNo = row.Field<string>("SourceArticleNo"),
                SourceArticleName = row.Field<string>("SourceArticleName"),
                ArticleName = row.Field<string>("ArticleName"),
                LocalizationCode = row.Field<string>("LocalizationCode"),

                IdentArticleNo = row.Field<int?>("IdentArticleNo"),
                IdentArticleName = row.Field<string>("IdentArticleName"),
                GeneralArticleNo = row.Field<Int16?>("GeneralArticleNo"),

                ActiveFlag = row.Field<bool>("ActiveFlag"),

                ArticlePackagingNo = row.Field<Int16?>("ArticlePackagingNo"),
                ArticlePackagingID = row.Field<Guid?>("ArticlePackagingID"),
                ArticlePackagingName = row.Field<string>("ArticlePackagingName")
            }))
        {
            this.Plant = plant;
            this.AllArticlesLoaded = allloaded;
        }

        private Plant m_Plant;

        public Plant Plant
        {
            get { return m_Plant; }
            set { m_Plant = value; }
        }

        private bool m_AllArticlesLoaded;

        public bool AllArticlesLoaded
        {
            get { return m_AllArticlesLoaded; }
            set { m_AllArticlesLoaded = value; }
        }

    }

    public class PlantArticle
    {
        public Int32 ArticleNo { get; set; }
        public Int16 CompanyArticleOrgNo { get; set; }
        public Int32 SourceNo { get; set; }
        public string SourceArticleNo { get; set; }
        public string SourceArticleName { get; set; }
        public string ArticleName { get; set; }
        public string LocalizationCode { get; set; }
        public Int32? IdentArticleNo { get; set; }
        public string IdentArticleName { get; set; }
        public Int16? GeneralArticleNo { get; set; }
        public string GeneralArticleName { get; set; }
        public bool ActiveFlag { get; set; }
        public Int16? ArticlePackagingNo { get; set; }
        public Guid? ArticlePackagingID { get; set; }
        public string ArticlePackagingName { get; set; }

        public string StrArticleNo
        {
            get
            {
                if (ArticleNo == 0)
                {
                    return string.Empty;
                }
                return ArticleNo.ToString();
            }
        }

        //public string SourceArticleNameLower
        //{
        //    get
        //    {
        //        if (!string.IsNullOrWhiteSpace(this.SourceArticleName))
        //        {
        //            return this.SourceArticleName.ToLower();
        //        }
        //        return string.Empty;
        //    }
        //}

        //public string ArticleNameLower
        //{
        //    get
        //    {
        //        if (!string.IsNullOrWhiteSpace(this.ArticleName))
        //        {
        //            return this.ArticleName.ToLower();
        //        }
        //        return string.Empty;
        //    }
        //}
    }
}
